#!/usr/bin/env python3

# Based on an example from https://plot.ly/matplotlib/fft/
import matplotlib.pyplot as plt
import numpy as np

Fs = 150.0;  # sampling rate
Ts = 1.0/Fs; # sampling interval
t = np.arange(0,1,Ts) # time vector

ff = 5;   # frequency of the signal
y1 = np.sin(2*np.pi*ff*t)
y2 = np.sin(2*np.pi*ff*t*3)

yy = y1 + y2

n = len(yy) # length of the signal
k = np.arange(n)
T = n/Fs
frq = k/T # two sides frequency range
frq = frq[range(n//2)] # one side frequency range

Y = np.fft.fft(yy)/n # fft computing and normalization
Y = Y[range(n//2)]

fig, ax = plt.subplots(2, 1)
ax[0].plot(t,y1)
ax[0].plot(t,y2)
ax[0].set_xlabel('Time')
ax[0].set_ylabel('Amplitude')
ax[1].plot(frq,abs(Y),'r') # plotting the spectrum
ax[1].set_xlabel('Freq (Hz)')
ax[1].set_ylabel('|Y(freq)|')

plt.tight_layout()
plt.savefig("plot.png")
